@@ -2,7 +2,7 @@
 Organ is a collection of tools for "digesting" tabular data.
 """
 
-VERSION = "0.3.0"
+VERSION = "0.4.0"
 
 def templategetter(tmpl):
     """
@@ -29,6 +29,9 @@ def sorter(expr):
     """
     order = ascending
     if not callable(expr):
+        if ',' in expr:
+            sorts = map(sorter, expr.split(','))
+            return multisorter(*sorts)
         if expr[0] == '-':
             order = descending
             expr = expr[1:]
@@ -39,6 +42,15 @@ def sorter(expr):
         return order(expr(a), expr(b))
     return _sort
 
+def multisorter(*sorts):
+    def _sort(aa, bb):
+        for sort in sorts:
+            order = sort(aa, bb)
+            if order != 0:
+                return order
+        return 0
+    return _sort
+
 def ascending(aa, bb):
     return (aa > bb and 1 or (aa < bb and -1 or 0))
 
